@@ -1,13 +1,12 @@
-from signal_cli_rest_api.app.schemas import GroupCreate, GroupUpdate, GroupOut
-from signal_cli_rest_api.app.utils import (
-    run_signal_cli_command,
-    read_groups,
-    save_attachment,
-)
-from signal_cli_rest_api.app.config import settings
 from typing import Any, List
+
 from fastapi import APIRouter
 
+from signal_cli_rest_api.app.config import settings
+from signal_cli_rest_api.app.schemas import GroupCreate, GroupOut, GroupUpdate
+from signal_cli_rest_api.app.utils import (read_groups, run_signal_cli_command,
+                                           save_attachment)
+
 router = APIRouter()
 
 
@@ -39,7 +38,7 @@ async def create_group(group: GroupCreate, number: str) -> Any:
 
     if group.avatar:
         cmd.append("-a")
-        save_attachment(group.avatar)
+        await save_attachment(group.avatar)
         cmd.append(f"{settings.signal_upload_path}{group.avatar.filename}")
 
     cmd += ["-m"]
@@ -63,7 +62,7 @@ async def edit_group(id: str, group: GroupUpdate, number: str) -> Any:
 
     if group.avatar:
         cmd.append("-a")
-        save_attachment(group.avatar)
+        await save_attachment(group.avatar)
         cmd.append(f"{settings.signal_upload_path}{group.avatar.filename}")
 
     if len(group.members) > 0:
