@@ -1,26 +1,25 @@
-from typing import Any, List
-from fastapi import APIRouter, BackgroundTasks
-from signal_cli_rest_api.app.schemas import (
-    MessageIncoming,
-    MessageOutgoing,
-    MessageSent,
-    ReactionOut,
-)
-from signal_cli_rest_api.app.utils import run_signal_cli_command, save_attachment
-from signal_cli_rest_api.app.config import settings
 import json
 import os
+from typing import Any, List
+
+from fastapi import APIRouter, BackgroundTasks
+
+from signal_cli_rest_api.app.config import settings
+from signal_cli_rest_api.app.schemas import (MessageIncoming, MessageOutgoing,
+                                             MessageSent, ReactionOut)
+from signal_cli_rest_api.app.utils import (run_signal_cli_command,
+                                           save_attachment)
 
 router = APIRouter()
 
 
 @router.get("/{number}", response_model=List[MessageIncoming])
-def get_messages(number: str) -> Any:
+async def get_messages(number: str) -> Any:
     """
     get messages
     """
 
-    response = run_signal_cli_command(["-u", number, "receive", "--json"])
+    response = await run_signal_cli_command(["-u", number, "receive", "--json"])
     return [json.loads(m) for m in response.split("\n") if m != ""]
 
 
@@ -34,19 +33,20 @@ async def send_message(
 
     cmd = ["-u", number, "send", "-m", message.text]
 
-    cmd += message.receivers
+    if message.group:
+        cmd.append("-g")
+        cmd.append(message.groupId)
+    else:
+        cmd += message.receivers
 
     if len(message.attachments) > 0:
         cmd.append("-a")
         for attachment in message.attachments:
-            save_attachment(attachment)
+            await save_attachment(attachment)
             attachment_path = f"{settings.signal_upload_path}{attachment.filename}"
             cmd.append(attachment_path)
             background_tasks.add_task(os.remove, attachment_path)
 
-    if message.group:
-        cmd.append("-g")
-
     response = await run_signal_cli_command(cmd)
 
     return MessageSent(**message.dict(), timestamp=response.split("\n")[0])
