@@ -1,9 +1,12 @@
-from signal_cli_rest_api.app.schemas import ProfileUpdate
-from signal_cli_rest_api.app.utils import run_signal_cli_command, save_attachment
-from signal_cli_rest_api.app.config import settings
-from typing import Any
-from fastapi import APIRouter, BackgroundTasks
 import os
+from typing import Any
+
+from fastapi import APIRouter, BackgroundTasks
+
+from signal_cli_rest_api.app.config import settings
+from signal_cli_rest_api.app.schemas import ProfileUpdate
+from signal_cli_rest_api.app.utils import (run_signal_cli_command,
+                                           save_attachment)
 
 router = APIRouter()
 
@@ -23,7 +26,7 @@ async def update_profile(profile: ProfileUpdate, number: str, background_tasks:
         cmd.append("--remove-avatar")
     elif profile.avatar:
         cmd.append("--avatar")
-        save_attachment(profile.avatar)
+        await save_attachment(profile.avatar)
         attachment_path = f"{settings.signal_upload_path}{profile.avatar.filename}"
         cmd.append(attachment_path)
         background_tasks.add_task(os.remove, attachment_path)
