@@ -1,10 +1,12 @@
+from io import BytesIO
 from typing import Any
+
+import pyqrcode
 from fastapi import APIRouter
 from starlette.responses import StreamingResponse
+
+from signal_cli_rest_api.app.schemas import Registration, Verification
 from signal_cli_rest_api.app.utils import run_signal_cli_command
-from signal_cli_rest_api.app.schemas import Verification, Registration
-from io import BytesIO
-import pyqrcode
 
 router = APIRouter()
 
@@ -37,6 +39,9 @@ async def register_number(registration: Registration, number: str) -> Any:
     if registration.voice_verification:
         cmd.append("--voice")
 
+    if registration.captcha:
+        cmd.append(["--captcha", registration.captcha] )
+
     await run_signal_cli_command(cmd)
     return registration
 
