@@ -1,5 +1,6 @@
-from typing import Optional, List, Optional, Any
 from datetime import datetime
+from typing import Any, List, Optional
+
 from pydantic import BaseModel
 
 
@@ -13,6 +14,7 @@ class MessageOutgoing(BaseModel):
     text: str
     receivers: List[str]
     group: bool = False
+    groupId: str
     attachments: List[AttachmentIn] = []
 
 
